'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.showMenu = exports.hideMenu = exports.toggleMenu = exports.fetchNotificationsFailure = exports.fetchNotificationsSuccess = exports.fetchNotificationsRequested = exports.fetchNotifications = undefined;

var _ActionTypes = require('../constants/ActionTypes');

var ActionTypes = _interopRequireWildcard(_ActionTypes);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj['default'] = obj; return newObj; } }

/**
 * This action starts the saga that fetches notifications
 * @returns {object} An action object with a type of FETCH_NOTIFICATIONS
 */
var fetchNotifications = exports.fetchNotifications = function fetchNotifications() {
  return {
    type: ActionTypes.FETCH_NOTIFICATIONS
  };
};

/**
 * This action that fetches notifications
 * @returns {object} An action object with a type of FETCH_NOTIFICATIONS_REQUESTED
 */
var fetchNotificationsRequested = exports.fetchNotificationsRequested = function fetchNotificationsRequested() {
  return {
    type: ActionTypes.FETCH_NOTIFICATIONS_REQUESTED
  };
};

/**
 * Dispatched when the request suceeds
 * @param {object} payload
 * @param {array} payload.authors The sideloaded array of authors
 * @param {array} payload.probes The array of probes
 * @returns {object} An action object with a type of FETCH_NOTIFICATIONS_SUCCESS
 * passing the probes and authors
 */
var fetchNotificationsSuccess = exports.fetchNotificationsSuccess = function fetchNotificationsSuccess(payload) {
  return {
    type: ActionTypes.FETCH_NOTIFICATIONS_SUCCESS,
    payload: payload
  };
};

/**
 * Dispatched when the request fails
 * @param {object} payload
 * @param {object} payload.error
 * @returns {object} An action object with a type of FETCH_NOTIFICATIONS_FAILURE
 * passin the error
 */
var fetchNotificationsFailure = exports.fetchNotificationsFailure = function fetchNotificationsFailure(payload) {
  return {
    type: ActionTypes.FETCH_NOTIFICATIONS_FAILURE,
    payload: payload
  };
};

var toggleMenu = exports.toggleMenu = function toggleMenu() {
  return { type: ActionTypes.TOGGLE_MENU };
};
var hideMenu = exports.hideMenu = function hideMenu() {
  return { type: ActionTypes.HIDE_MENU };
};
var showMenu = exports.showMenu = function showMenu() {
  return { type: ActionTypes.SHOW_MENU };
};