'use strict';

var _ava = require('ava');

var _ava2 = _interopRequireDefault(_ava);

var _ActionTypes = require('../constants/ActionTypes');

var ActionTypes = _interopRequireWildcard(_ActionTypes);

var _notifications = require('./notifications');

var _notifications2 = _interopRequireDefault(_notifications);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj['default'] = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

(0, _ava2['default'])('when the sate is undefined it returns the initial state dormant', function (t) {
  var result = (0, _notifications2['default'])(undefined, { type: 'UNKNOWN_ACTION' });

  var expected = { fetchStatus: 'dormant', authors: [], probes: [] };

  t.deepEqual(result, expected);
});

(0, _ava2['default'])('when no action matches, returns the supplied state', function (t) {
  var state = { fetchStatus: 'dormant' };

  var result = (0, _notifications2['default'])(state, { type: 'UNKNOWN_ACTION' });

  t.deepEqual(result, state);
});

(0, _ava2['default'])('when action is FETCH_NOTIFICATIONS_REQUESTED, sets the fetch status to fetching', function (t) {
  var stateBefore = { fetchStatus: 'dormant' };
  var action = { type: ActionTypes.FETCH_NOTIFICATIONS_REQUESTED };
  var stateAfter = { fetchStatus: 'fetching' };

  var result = (0, _notifications2['default'])(stateBefore, action);

  t.deepEqual(result, stateAfter);
});

(0, _ava2['default'])('when action is FETCH_NOTIFICATIONS_FAILURE, adds an error object', function (t) {
  var stateBefore = { fetchStatus: 'fetching' };
  var error = { message: 'its broken' };
  var action = {
    type: ActionTypes.FETCH_NOTIFICATIONS_FAILURE,
    payload: {
      error: error
    }
  };
  var stateAfter = {
    fetchStatus: 'failed',
    error: {
      message: 'its broken'
    }
  };

  var result = (0, _notifications2['default'])(stateBefore, action);

  t.deepEqual(result, stateAfter);
});

(0, _ava2['default'])('when action is FETCH_NOTIFICATIONS_SUCCESS, adds sorted probes and authors object', function (t) {
  var stateBefore = {
    fetchStatus: 'fetching'
  };
  var action = {
    type: ActionTypes.FETCH_NOTIFICATIONS_SUCCESS,
    payload: {
      probes: [{ id: 1, messages: [{ id: 1, sentAt: '2016-08-09T10:17:31+00:00' }] }, { id: 2, messages: [{ id: 2, sentAt: '2016-09-09T10:17:31+00:00' }] }],
      authors: [{ id: 2 }]
    }
  };
  var stateAfter = {
    fetchStatus: 'success',
    probes: [{ id: 2, messages: [{ id: 2, sentAt: '2016-09-09T10:17:31+00:00' }] }, { id: 1, messages: [{ id: 1, sentAt: '2016-08-09T10:17:31+00:00' }] }],
    authors: [{ id: 2 }]
  };

  var result = (0, _notifications2['default'])(stateBefore, action);

  t.deepEqual(result, stateAfter);
});